Children

Struct Children 

pub struct Children(pub Cow<'static, str>);
Pre-rendered inner HTML produced by rsx!.

Phase 2c (rsx!) will produce Children values by recursively rendering inner nodes. You can also build them directly from strings or Markup.

Tuple Fields

0: Cow<'static, str>

Implementations

Source

impl Children

pub fn empty() -> Self

An empty children fragment (allocates nothing).